package tech.nevets.tvpn;

import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.net.http.HttpClient;
import java.net.http.HttpRequest;
import java.net.http.HttpResponse;
import java.util.Map;

public class Utils {
    public static final File APP_DIR = new File("./tvpn/");
    public static final String WG_CONF_DIR = "C:\\Program Files\\WireGuard\\Data\\Configurations\\";
    public static final String API_ENDPOINT_BASE = "http://tvpn.lan/";

    static {
        if (!APP_DIR.exists()) APP_DIR.mkdirs();
    }

    public static String get(URI url, Map<String, String> headers) {
        HttpClient client = HttpClient.newHttpClient();
        HttpRequest.Builder reqBuilder = HttpRequest.newBuilder()
                .GET()
                .uri(url);
        for (Map.Entry<String, String> header : headers.entrySet()) {
            reqBuilder.header(header.getKey(), header.getValue());
        }
        HttpRequest req = reqBuilder.build();
        HttpResponse<String> res;
        try {
            res = client.send(req, HttpResponse.BodyHandlers.ofString());
            return res.body();
        } catch (IOException | InterruptedException e) {
            e.printStackTrace();
            return "";
        }
    }

    public static String post(URI url, Map<String, String> headers, HttpRequest.BodyPublisher bodyPub) {
        HttpClient client = HttpClient.newHttpClient();
        HttpRequest.Builder reqBuilder = HttpRequest.newBuilder()
                .POST(bodyPub)
                .uri(url);
        for (Map.Entry<String, String> header : headers.entrySet()) {
            reqBuilder.header(header.getKey(), header.getValue());
        }
        HttpRequest req = reqBuilder.build();
        HttpResponse<String> res;
        try {
            res = client.send(req, HttpResponse.BodyHandlers.ofString());
            return res.body();
        } catch (IOException | InterruptedException e) {
            e.printStackTrace();
            return "";
        }
    }
}
