package tech.nevets.tvpn.auth;

import com.sun.net.httpserver.Headers;
import com.sun.net.httpserver.HttpExchange;
import com.sun.net.httpserver.HttpHandler;
import com.sun.net.httpserver.HttpServer;

import java.io.IOException;
import java.io.OutputStream;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.util.List;
import java.util.concurrent.CompletableFuture;

public class AuthServer {
    private HttpServer server;

    public AuthServer(CompletableFuture<String> cf) {
        try {
            server = HttpServer.create(new InetSocketAddress(InetAddress.getLoopbackAddress(), 8342), 0);
            server.createContext("/", new AuthHandler(cf));
            server.setExecutor(null);
            server.start();

            System.out.println("Server is running on port 8342");
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void stop() {
        server.stop(0);
    }

    // define a custom HttpHandler
    static class AuthHandler implements HttpHandler {
        private CompletableFuture<String> cf;

        public AuthHandler(CompletableFuture<String> cf) {
            this.cf = cf;
        }

        @Override
        public void handle(HttpExchange exchange) throws IOException {
            // handle the request
            Headers headers = exchange.getRequestHeaders();
            List<String> strHeaders = headers.get("Token");
            String response;
            int status;
            String token = "";
            if (exchange.getRequestMethod().equals("POST")) {
                if (strHeaders == null || strHeaders.isEmpty()) {
                    response = "Error, not token found.";
                    status = 412;
                } else {
                    response = "Successfully authenticated, you can now return to the app!";
                    status = 200;
                    token = strHeaders.getFirst();
                }
            } else {
                response = "Invalid Request Method";
                status = 405;
            }
            exchange.sendResponseHeaders(status, response.length());
            OutputStream os = exchange.getResponseBody();

            os.write(response.getBytes());
            os.flush();
            os.close();

            if (status == 200) {
                cf.complete(token);
            }
        }
    }
}
